==> gradle-2.2-rc-2-src.zip: gradle-2.2-rc-2/subprojects/language-native/src/main/java/org/gradle/language/nativeplatform/internal/AbstractHeaderExportingSourceSet.java <==
/*
 * Copyright 2013 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.gradle.language.nativeplatform.internal;

import org.gradle.api.Action;
import org.gradle.api.file.SourceDirectorySet;
import org.gradle.api.internal.file.DefaultSourceDirectorySet;
import org.gradle.api.internal.file.FileResolver;
import org.gradle.language.nativeplatform.HeaderExportingSourceSet;
import org.gradle.language.base.FunctionalSourceSet;
import org.gradle.language.base.LanguageSourceSet;
import org.gradle.language.base.internal.AbstractLanguageSourceSet;

/**
 * A convenience base class for implementing language source sets with dependencies and exported headers.
 */
public abstract class AbstractHeaderExportingSourceSet extends AbstractLanguageSourceSet
        implements HeaderExportingSourceSet, LanguageSourceSet {

    private final DefaultSourceDirectorySet exportedHeaders;
    private final DefaultSourceDirectorySet implicitHeaders;

    public AbstractHeaderExportingSourceSet(String name, FunctionalSourceSet parent, FileResolver fileResolver, String typeName, SourceDirectorySet source) {
        super(name, parent, typeName, source);
        this.exportedHeaders = new DefaultSourceDirectorySet("exported headers", fileResolver);
        this.implicitHeaders = new DefaultSourceDirectorySet("implicit headers", fileResolver);
    }

    public SourceDirectorySet getExportedHeaders() {
        return exportedHeaders;
    }

    public void exportedHeaders(Action<? super SourceDirectorySet> config) {
        config.execute(getExportedHeaders());
    }

    public SourceDirectorySet getImplicitHeaders() {
        return implicitHeaders;
    }
}

==> gradle-2.3-rc-4-src.zip: gradle-2.3-rc-4/subprojects/language-native/src/main/java/org/gradle/language/nativeplatform/internal/AbstractHeaderExportingSourceSet.java <==
/*
 * Copyright 2013 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.gradle.language.nativeplatform.internal;

import org.gradle.api.Action;
import org.gradle.api.file.SourceDirectorySet;
import org.gradle.api.internal.file.DefaultSourceDirectorySet;
import org.gradle.api.internal.file.FileResolver;
import org.gradle.language.base.LanguageSourceSet;
import org.gradle.language.base.internal.AbstractLanguageSourceSet;
import org.gradle.language.nativeplatform.HeaderExportingSourceSet;

/**
 * A convenience base class for implementing language source sets with dependencies and exported headers.
 */
public abstract class AbstractHeaderExportingSourceSet extends AbstractLanguageSourceSet
        implements HeaderExportingSourceSet, LanguageSourceSet {

    private final DefaultSourceDirectorySet exportedHeaders;
    private final DefaultSourceDirectorySet implicitHeaders;

    public AbstractHeaderExportingSourceSet(String name, String parent, FileResolver fileResolver, String typeName, SourceDirectorySet source) {
        super(name, parent, typeName, source);
        this.exportedHeaders = new DefaultSourceDirectorySet("exported headers", fileResolver);
        this.implicitHeaders = new DefaultSourceDirectorySet("implicit headers", fileResolver);
    }

    public SourceDirectorySet getExportedHeaders() {
        return exportedHeaders;
    }

    public void exportedHeaders(Action<? super SourceDirectorySet> config) {
        config.execute(getExportedHeaders());
    }

    public SourceDirectorySet getImplicitHeaders() {
        return implicitHeaders;
    }
}
